(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms'), require('@tiptap/extension-floating-menu'), require('@tiptap/extension-bubble-menu')) :
    typeof define === 'function' && define.amd ? define('ngx-tiptap', ['exports', '@angular/core', '@angular/forms', '@tiptap/extension-floating-menu', '@tiptap/extension-bubble-menu'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-tiptap'] = {}, global.ng.core, global.ng.forms, global.extensionFloatingMenu, global.extensionBubbleMenu));
}(this, (function (exports, core, forms, extensionFloatingMenu, extensionBubbleMenu) { 'use strict';

    var EditorDirective = /** @class */ (function () {
        function EditorDirective(el, _renderer) {
            var _this = this;
            this.el = el;
            this._renderer = _renderer;
            this.outputFormat = 'html';
            this.onChange = function () { };
            this.onTouched = function () { };
            this.handleChange = function (_a) {
                var transaction = _a.transaction;
                if (!transaction.docChanged) {
                    return;
                }
                if (_this.outputFormat === 'html') {
                    _this.onChange(_this.editor.getHTML());
                    return;
                }
                _this.onChange(_this.editor.getJSON());
            };
        }
        // Writes a new value to the element.
        // This methods is called when programmatic changes from model to view are requested.
        EditorDirective.prototype.writeValue = function (value) {
            if (!value) {
                return;
            }
            if (!this.outputFormat && typeof value === 'string') {
                this.outputFormat = 'html';
            }
            this.editor.chain().setContent(value, false).run();
        };
        // Registers a callback function that is called when the control's value changes in the UI.
        EditorDirective.prototype.registerOnChange = function (fn) {
            this.onChange = fn;
        };
        // Registers a callback function that is called by the forms API on initialization to update the form model on blur.
        EditorDirective.prototype.registerOnTouched = function (fn) {
            this.onTouched = fn;
        };
        // Called by the forms api to enable or disable the element
        EditorDirective.prototype.setDisabledState = function (isDisabled) {
            this.editor.setEditable(!isDisabled);
            this._renderer.setProperty(this.el.nativeElement, 'disabled', isDisabled);
        };
        EditorDirective.prototype.ngOnInit = function () {
            var _this = this;
            if (!this.editor) {
                throw new Error('Required: Input `editor`');
            }
            // take the inner contents and clear the block
            var innerHTML = this.el.nativeElement.innerHTML;
            this.el.nativeElement.innerHTML = '';
            // insert the editor in the dom
            this.el.nativeElement.appendChild(this.editor.options.element.firstChild);
            // update the options for the editor
            this.editor.setOptions({ element: this.el.nativeElement });
            // update content to the editor
            if (innerHTML) {
                this.editor.chain().setContent(innerHTML, false).run();
            }
            // register blur handler to update `touched` property
            this.editor.on('blur', function () {
                _this.onTouched();
            });
            // register transaction handler to emit changes on update
            this.editor.on('transaction', this.handleChange);
        };
        EditorDirective.prototype.ngOnDestroy = function () {
            this.editor.destroy();
        };
        return EditorDirective;
    }());
    EditorDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'tiptap, [tiptap], tiptap-editor, [tiptapEditor]',
                    providers: [{
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return EditorDirective; }),
                            multi: true
                        }]
                },] }
    ];
    EditorDirective.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: core.Renderer2 }
    ]; };
    EditorDirective.propDecorators = {
        editor: [{ type: core.Input }],
        outputFormat: [{ type: core.Input }]
    };

    var FloatingMenuDirective = /** @class */ (function () {
        function FloatingMenuDirective(_el) {
            this._el = _el;
            this.tippyOptions = {};
        }
        FloatingMenuDirective.prototype.ngOnInit = function () {
            this.editor.registerPlugin(extensionFloatingMenu.FloatingMenuPlugin({
                editor: this.editor,
                element: this._el.nativeElement,
                tippyOptions: this.tippyOptions
            }));
        };
        FloatingMenuDirective.prototype.ngOnDestroy = function () {
            this.editor.unregisterPlugin(extensionFloatingMenu.FloatingMenuPluginKey);
        };
        return FloatingMenuDirective;
    }());
    FloatingMenuDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'tiptap-floting-menu, [tiptapFloatingMenu]'
                },] }
    ];
    FloatingMenuDirective.ctorParameters = function () { return [
        { type: core.ElementRef }
    ]; };
    FloatingMenuDirective.propDecorators = {
        editor: [{ type: core.Input }],
        tippyOptions: [{ type: core.Input }]
    };

    var BubbleMenuDirective = /** @class */ (function () {
        function BubbleMenuDirective(_el) {
            this._el = _el;
            this.tippyOptions = {};
        }
        BubbleMenuDirective.prototype.ngOnInit = function () {
            this.editor.registerPlugin(extensionBubbleMenu.BubbleMenuPlugin({
                editor: this.editor,
                element: this._el.nativeElement,
                tippyOptions: this.tippyOptions
            }));
        };
        BubbleMenuDirective.prototype.ngOnDestroy = function () {
            this.editor.unregisterPlugin(extensionBubbleMenu.BubbleMenuPluginKey);
        };
        return BubbleMenuDirective;
    }());
    BubbleMenuDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'tiptap-bubble-menu, [tiptapBubbleMenu]'
                },] }
    ];
    BubbleMenuDirective.ctorParameters = function () { return [
        { type: core.ElementRef }
    ]; };
    BubbleMenuDirective.propDecorators = {
        editor: [{ type: core.Input }],
        tippyOptions: [{ type: core.Input }]
    };

    var NgxTiptapModule = /** @class */ (function () {
        function NgxTiptapModule() {
        }
        return NgxTiptapModule;
    }());
    NgxTiptapModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        EditorDirective,
                        FloatingMenuDirective,
                        BubbleMenuDirective,
                    ],
                    exports: [
                        EditorDirective,
                        FloatingMenuDirective,
                        BubbleMenuDirective
                    ]
                },] }
    ];

    /*
     * Public API Surface of ngx-tiptap
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.BubbleMenuDirective = BubbleMenuDirective;
    exports.EditorDirective = EditorDirective;
    exports.FloatingMenuDirective = FloatingMenuDirective;
    exports.NgxTiptapModule = NgxTiptapModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-tiptap.umd.js.map
